@@ -94,7 +94,9 @@ def validate_lims(
             cursor,
             lims_id,
         )
-    console.print(from_AssetValidationResult(validation) for validation in validated)
+    console.print("Verified lims:")
+    for validation in validated:
+        console.print(from_AssetValidationResult(validation))
 
 
 @app.command()
