@@ -83,7 +83,7 @@ def validate_lims_upload(
             update_asset_validation_result(
                 client[table_name].validations,
                 lims_id,
-                validation.asset_type,
+                validation.manifest.asset_type,
                 {"lims_verified": True},
             )
             lims_verified.append(validation)
