@@ -29,7 +29,7 @@ def update_asset_validation_result(table, lims_id: str, name: str, updates: dict
     return table.update_one(
         {
             "lims_id": lims_id,
-            "name": name,
+            "manifest.asset_type": name,
         },
         {
             "$set": updates,
